#+TITLE: Footnote Tooltips (Test v2): an Attempt
#+AUTHOR: Juan Manuel Macías


#+begin_src emacs-lisp :tangle no :results silent
  (org-babel-load-file (buffer-file-name))
#+end_src

#+begin_src emacs-lisp
  ;;;  -*- lexical-binding: t; -*-
#+end_src

#+begin_src emacs-lisp
  (define-minor-mode my-org-fn-tooltip-mode
    "TODO"
    :lighter "fnt"
    :global nil
    (if my-org-fn-tooltip-mode
	(progn
	  (advice-add 'org-activate-footnote-links
		      :override
		      #'my-org-activate-footnote-links)
	  (advice-add 'org-mark-ring-goto
		      :after
		      #'my-org-fn-make-tooltips)
	  (advice-add 'org-edit-src-exit
		      :after
		      #'my-org-fn-make-tooltips))
      (advice-remove 'org-activate-footnote-links
		     #'my-org-activate-footnote-links)
      (advice-remove 'org-mark-ring-goto
		     #'my-org-fn-make-tooltips)
      (advice-remove 'org-edit-src-exit
		     #'my-org-fn-make-tooltips)))
#+end_src

#+begin_src emacs-lisp
(defun my-org-fn-get-def ()
  (interactive)
  (let* ((el (org-element-context))
	 (label (org-element-property :label el))
	 (def (nth 3 (org-footnote-get-definition label))))
    def))
#+end_src


You need to replace =org-activate-footnote-links= with this version:

#+begin_src emacs-lisp
(defun my-org-activate-footnote-links (limit)
  "Add text properties for footnotes."
  (let ((fn (org-footnote-next-reference-or-definition limit)))
    (when fn
      (let* ((beg (nth 1 fn))
	     (end (nth 2 fn))
	     (label (car fn))
	     (tooltip (my-org-fn-get-def))
	     (referencep (/= (line-beginning-position) beg)))
	(when (and referencep (nth 3 fn))
	  (save-excursion
	    (goto-char beg)
	    (search-forward (or label "fn:"))
	    (org-remove-flyspell-overlays-in beg (match-end 0))))
	(add-text-properties beg end
			     (list 'mouse-face 'highlight
				   'keymap org-mouse-map
				   'help-echo
				   (if referencep (concat "Footnote: " tooltip)
				     "Footnote definition")
				   'font-lock-fontified t
				   'font-lock-multiline t
				   'face 'org-footnote))))))
#+end_src


Add tooltips to all the document footnote references with the content of each footnote
definition:

#+begin_src emacs-lisp
  (defun my-org-fn-make-tooltips ()
    "TODO"
    (interactive)
    (org-element-map (org-element-parse-buffer) 'footnote-reference
      (lambda (ref)
	(let* ((label (org-element-property :label ref))
	       (label-from (org-element-property :begin ref))
	       (label-to (org-element-property :end ref))
	       (def (org-with-wide-buffer
		     (org-footnote-goto-definition label)
		     (let* ((e (org-element-context))
			    (from (org-element-property :contents-begin e))
			    (to (org-element-property :contents-end e)))
		       (buffer-substring-no-properties from to))))
	       (tooltip (concat "Footnote:" def)))
	  (add-text-properties label-from label-to
			       `(help-echo
				 ,tooltip))))
      nil nil))
#+end_src



#+begin_src emacs-lisp
(add-hook 'org-mode-hook #'my-org-fn-tooltip-mode)
#+end_src
